@@ -482,3 +482,33 @@ inheritance_override_here_check = """
         -->[1]::sum;
     }
     """
+
+dot_private_hidden = """
+    node a {
+        has x="56";
+        has private j="5566669";
+    }
+
+    walker init {
+        n1 = spawn here --> node::a;
+        n2 = spawn here --> node::a;
+    }
+    """
+
+check_destroy_node_has_var = """
+    node a {
+        has x;
+    }
+
+    walker create {
+        n = spawn here --> node::a;
+        n.x = spawn node::a;
+        report n.x.type;
+    }
+
+    walker remove {
+        n=-->[0];
+        destroy n.x;
+        report n.x.type;
+    }
+"""
